summaryrefslogtreecommitdiff
path: root/lib/asn1/test/asn1_SUITE_data
diff options
context:
space:
mode:
Diffstat (limited to 'lib/asn1/test/asn1_SUITE_data')
-rw-r--r--lib/asn1/test/asn1_SUITE_data/Comment.asn2
-rw-r--r--lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py6
-rw-r--r--lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn2
-rw-r--r--lib/asn1/test/asn1_SUITE_data/Fragmented.asn19
-rw-r--r--lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn2
-rw-r--r--lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn2
-rw-r--r--lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn4
-rw-r--r--lib/asn1/test/asn1_SUITE_data/Nortel.asn4
-rw-r--r--lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn12
-rw-r--r--lib/asn1/test/asn1_SUITE_data/RANAP.asn14
-rw-r--r--lib/asn1/test/asn1_SUITE_data/SwCDR.py2
-rw-r--r--lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn6
-rw-r--r--lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn12
-rw-r--r--lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn16
-rw-r--r--lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn2
-rw-r--r--lib/asn1/test/asn1_SUITE_data/testobj.erl12
16 files changed, 38 insertions, 29 deletions
diff --git a/lib/asn1/test/asn1_SUITE_data/Comment.asn b/lib/asn1/test/asn1_SUITE_data/Comment.asn
index c2a5abd633..af439a1ce4 100644
--- a/lib/asn1/test/asn1_SUITE_data/Comment.asn
+++ b/lib/asn1/test/asn1_SUITE_data/Comment.asn
@@ -4,7 +4,7 @@ BEGIN
/* comments as to the 2002 standard
-this is the new added way of commenting multile lines */
+this is the new added way of commenting multiple lines */
/* it is also allowed to have -- old kind of comment signs inside
this new variant. The two dashes will lose their meaning as a comment
diff --git a/lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py b/lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py
index 2c25f81235..67cd9eae96 100644
--- a/lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py
+++ b/lib/asn1/test/asn1_SUITE_data/CommonDataTypes.py
@@ -923,7 +923,7 @@ ConnectUUIE ::= SEQUENCE
-- @prop dataType
--
-- @descr This parameter holds connection data that are specific for
--- certain types of Equipments.
+-- certain types of Equipment.
-- @
--
-- ---------------------------------
@@ -958,7 +958,7 @@ ConnectionIdentifier ::= ObjectIdentifier
-- @prop dataType
--
-- @descr This parameter specifies information that are of interest for
--- the functionallity handled by component Connection Handler.
+-- the functionality handled by component Connection Handler.
-- @
--
-- ---------------------------------
@@ -1541,7 +1541,7 @@ EquipmentAddressLAN ::= SEQUENCE
--
-- @prop dataType
--
--- @descr Contains the retreived data.
+-- @descr Contains the retrieved data.
--
-- @
--
diff --git a/lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn b/lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn
index 3b811dafe6..24dd8e85e8 100644
--- a/lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn
+++ b/lib/asn1/test/asn1_SUITE_data/EUTRA-RRC-Definitions.asn
@@ -3124,7 +3124,7 @@ maxCellMeas INTEGER ::= 32 -- Maximum number of entries in each of the neigh
-- cell lists in a measurement object
maxCellReport INTEGER ::= 8 -- Maximum number of reported cells
maxDRB INTEGER ::= 11 -- Maximum number of Data Radio Bearers
-maxEARFCN INTEGER ::= 65535 -- Maximum value of EUTRA carrier fequency
+maxEARFCN INTEGER ::= 65535 -- Maximum value of EUTRA carrier frequency
maxFreq INTEGER ::= 8 -- Maximum number of EUTRA carrier frequencies
maxCellInfo-GERAN-r9 INTEGER ::= 32 -- Maximum number of GERAN cells for which system in-
-- formation can be provided as redirection assistance
diff --git a/lib/asn1/test/asn1_SUITE_data/Fragmented.asn1 b/lib/asn1/test/asn1_SUITE_data/Fragmented.asn1
index bfc939737f..e784feff8c 100644
--- a/lib/asn1/test/asn1_SUITE_data/Fragmented.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/Fragmented.asn1
@@ -21,4 +21,13 @@ PDU ::= SEQUENCE {
arg FUNCTION.&ArgumentType ({ObjSet}{@code})
}
+IntBoolSeqs ::= SEQUENCE (SIZE (1..65536)) OF IntBoolSeq
+
+IntBoolSeqsU ::= SEQUENCE OF IntBoolSeq
+
+IntBoolSeq ::= SEQUENCE {
+ a INTEGER,
+ b BOOLEAN
+}
+
END
diff --git a/lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn b/lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn
index 3401f9599f..76eedc0d2c 100644
--- a/lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn
+++ b/lib/asn1/test/asn1_SUITE_data/H235-SECURITY-MESSAGES.asn
@@ -135,7 +135,7 @@ KeySignedMaterial ::= SEQUENCE {
generalId Identifier, -- slave's alias
mrandom RandomVal, -- master's random value
srandom RandomVal OPTIONAL, -- slave's random value
- timeStamp TimeStamp OPTIONAL, -- master's timestamp for unsolicted EU
+ timeStamp TimeStamp OPTIONAL, -- master's timestamp for unsolicited EU
encrptval ENCRYPTED {EncodedKeySyncMaterial }
}
EncodedKeySignedMaterial ::= TYPE-IDENTIFIER.&Type (KeySignedMaterial)
diff --git a/lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn b/lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn
index fb092f3f9c..9cd8fbea84 100644
--- a/lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn
+++ b/lib/asn1/test/asn1_SUITE_data/IN-CS-1-Datatypes.asn
@@ -1431,7 +1431,7 @@ ServiceInteractionIndicators ::=
-- The following example is listed to illustrate the use of this parameter:
-- CallToBeDiverted Allowed/NotAllowed Indicator
-- If the CallToBeDiverted indicator is set to NotAllowed, the destination exchange shall not allow any
--- divertion on the subjected call. By this, each service can pass the applicable indicators to inform the
+-- diversion on the subjected call. By this, each service can pass the applicable indicators to inform the
-- destination exchange of how specific services are to be handled.
ServiceKey ::=
Integer4
diff --git a/lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn b/lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn
index 81c07a2dab..fca635bb1f 100644
--- a/lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn
+++ b/lib/asn1/test/asn1_SUITE_data/Mvrasn-11-4.asn
@@ -140,8 +140,8 @@ InsertSubscriberDataArg ::= SEQUENCE {
-- compiler. Instead of this line the complete definition of
-- "Subscriberdata" has been inserted.
--
--- This results in the same behaviour of the deocder/encoder but
--- means only a replication of the ASN.1 definiton here.
+-- This results in the same behaviour of the decoder/encoder but
+-- means only a replication of the ASN.1 definition here.
--
msisdn [1] ISDN-AddressString OPTIONAL,
category [2] Category OPTIONAL,
diff --git a/lib/asn1/test/asn1_SUITE_data/Nortel.asn b/lib/asn1/test/asn1_SUITE_data/Nortel.asn
index a27c78a0b5..57a4434f2e 100644
--- a/lib/asn1/test/asn1_SUITE_data/Nortel.asn
+++ b/lib/asn1/test/asn1_SUITE_data/Nortel.asn
@@ -153,7 +153,7 @@ LocationAreaCode ::= OCTET STRING (SIZE(2))
CallEventRecord ::= CHOICE
{
--- Record values 0..16 are 3G curcuit switch specifick
+-- Record values 0..16 are 3G circuit switch specifick
--
-- sgsnPDPRecord [20] SGSNPDPRecord,
ggsnPDPRecord [21] GGSNPDPRecord
@@ -372,7 +372,7 @@ FFDAppendIndicator ::= BOOLEAN
FreeFormatData ::= OCTET STRING (SIZE(1..160))
--
- -- Free formated data as sent in the FurnishChargingInformationGPRS
+ -- Free formatted data as sent in the FurnishChargingInformationGPRS
-- see TS 29.078
--
diff --git a/lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn1 b/lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn1
index 714a682160..01c5be2166 100644
--- a/lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/PKIX1Explicit93.asn1
@@ -172,7 +172,7 @@ EntryExtensionSet EXTENSION ::= { reasonCode |
invalidityDate |
certificateIssuer }
- -- information object classes used in the defintion --
+ -- information object classes used in the definition --
-- of certificates and CRLs --
-- Parameterized Type SIGNED --
diff --git a/lib/asn1/test/asn1_SUITE_data/RANAP.asn1 b/lib/asn1/test/asn1_SUITE_data/RANAP.asn1
index 55fb58b163..e821703036 100644
--- a/lib/asn1/test/asn1_SUITE_data/RANAP.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/RANAP.asn1
@@ -872,7 +872,7 @@ RAB-Parameters ::= SEQUENCE {
transferDelay TransferDelay OPTIONAL
-- This IE is only present when traffic class indicates Conversational or Streaming --,
trafficHandlingPriority TrafficHandlingPriority OPTIONAL
- -- This IE is only present when traffic class indicates Interactiv --,
+ -- This IE is only present when traffic class indicates Interactive --,
allocationOrRetentionPriority AllocationOrRetentionPriority OPTIONAL,
sourceStatisticsDescriptor SourceStatisticsDescriptor OPTIONAL
-- This IE is only present when traffic class indicates Conversational or Streaming --,
@@ -1640,7 +1640,7 @@ RelocationCancelAcknowledgeExtensions RANAP-PROTOCOL-EXTENSION ::= {
-- **************************************************************
--
--- SRNS CONTEXT TRANSFER OPEARATION
+-- SRNS CONTEXT TRANSFER OPERATION
--
-- **************************************************************
diff --git a/lib/asn1/test/asn1_SUITE_data/SwCDR.py b/lib/asn1/test/asn1_SUITE_data/SwCDR.py
index 9492183cdf..1ed9c32aba 100644
--- a/lib/asn1/test/asn1_SUITE_data/SwCDR.py
+++ b/lib/asn1/test/asn1_SUITE_data/SwCDR.py
@@ -199,7 +199,7 @@ StartDate ::= OCTET STRING (SIZE (8))
StartTime ::= OCTET STRING (SIZE (6))
CallDuration ::= INTEGER
--- Expressed as number of millseconds
+-- Expressed as number of milliseconds
Cellrate ::= INTEGER
-- Value range 0-2^64
diff --git a/lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn b/lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn
index 9ecfa688a2..b614e86bba 100644
--- a/lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn
+++ b/lib/asn1/test/asn1_SUITE_data/nbapsystem/NBAP-PDU-Contents.asn
@@ -5606,13 +5606,13 @@ DL-CCTrCH-InformationAddItem-RL-ReconfPrepTDD-ExtIEs NBAP-PROTOCOL-EXTENSION ::
{ ID id-DL-DPCH-LCR-InformationAddList-RL-ReconfPrepTDD CRITICALITY reject EXTENSION DL-DPCH-LCR-InformationAddList-RL-ReconfPrepTDD PRESENCE optional }| -- Applicable to 1.28Mcps TDD only
-- This DPCH Information is the for the first RL repetition, DPCH information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
{ ID id-CCTrCH-Initial-DL-Power-RL-ReconfPrepTDD CRITICALITY ignore EXTENSION DL-Power PRESENCE optional }|
--- This DL Power inforrmation is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
+-- This DL Power information is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
{ ID id-TDD-TPC-DownlinkStepSize-InformationAdd-RL-ReconfPrepTDD CRITICALITY reject EXTENSION TDD-TPC-DownlinkStepSize PRESENCE optional}|
-- This DL step size is the for the first RL repetition, DL step size information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
{ ID id-CCTrCH-Maximum-DL-Power-InformationAdd-RL-ReconfPrepTDD CRITICALITY ignore EXTENSION DL-Power PRESENCE optional }|
--- This DL Power inforrmation is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
+-- This DL Power information is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
{ ID id-CCTrCH-Minimum-DL-Power-InformationAdd-RL-ReconfPrepTDD CRITICALITY ignore EXTENSION DL-Power PRESENCE optional }|
--- This DL Power inforrmation is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
+-- This DL Power information is the for the first RL repetition, DL power information for RL repetitions 2 and on, should be defined in MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD
{ ID id-RL-ID CRITICALITY ignore EXTENSION RL-ID PRESENCE optional }|
-- This is the RL ID for the first RL repetition
{ ID id-multipleRL-ul-DPCH-InformationList CRITICALITY reject EXTENSION MultipleRL-DL-DPCH-InformationAddList-RL-ReconfPrepTDD PRESENCE optional },
diff --git a/lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn1 b/lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn1
index f912966c72..7da299c789 100644
--- a/lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/rfcs/AlgorithmInformation-2009.asn1
@@ -50,7 +50,7 @@ ParamOptions ::= ENUMERATED {
-- Additional information such as the length of the hash could have
-- been encoded. Without a clear understanding of what information
-- is needed by applications, such extraneous information was not
--- considered to be of sufficent importance.
+-- considered to be of sufficient importance.
--
-- Example:
-- mda-sha1 DIGEST-ALGORITHM ::= {
diff --git a/lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1 b/lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1
index a57a276704..3765eb5b65 100644
--- a/lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1
+++ b/lib/asn1/test/asn1_SUITE_data/rfcs/ISO8571-FTAM.asn1
@@ -286,7 +286,7 @@ F-OPEN-response ::= SEQUENCE {
-- This flag is set if the responder is going to follow this response
-- by a P-ALTER-CONTEXT exchange.
--The following are conditional on the negotiation of the concecutive access
- -- or concurent access functional units.
+ -- or concurrent access functional units.
degree-of-overlap Degree-Of-Overlap OPTIONAL,
transfer-window [7] IMPLICIT INTEGER OPTIONAL
}
@@ -571,7 +571,7 @@ Change-Attributes ::= [APPLICATION 8] IMPLICIT SEQUENCE {
-- This Parameter tan only be sent when the
-- enhanced-filestore-management functional unit is available.
--- Atleast one attribute shall be present in the Change-Attributes
+-- At least one attribute shall be present in the Change-Attributes
-- Parameter on the request PDU.
Charging ::=
[APPLICATION 9] IMPLICIT
@@ -1350,7 +1350,7 @@ Attribute-Extensions-Pattern ::=
{@.extension-attribute-identifier})
}}
--- conjunction with the extention attribute in Order to
+-- conjunction with the extension attribute in Order to
-- perform Pattern matthing operations on it. it may be
-- defined in terms of other Patterns within this
-- Standard.
diff --git a/lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn b/lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn
index e905c44077..46c919b772 100644
--- a/lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn
+++ b/lib/asn1/test/asn1_SUITE_data/tcapsystem/MAP-MS-DataTypes.asn
@@ -2100,7 +2100,7 @@ LocationInformation ::= SEQUENCE {
-- sai-Present indicates that the cellGlobalIdOrServiceAreaIdOrLAI parameter contains
-- a Service Area Identity.
-- currentLocationRetrieved shall be present
--- if the location information were retrieved after a successfull paging.
+-- if the location information were retrieved after a successful paging.
LocationInformationGPRS ::= SEQUENCE {
cellGlobalIdOrServiceAreaIdOrLAI [0] CellGlobalIdOrServiceAreaIdOrLAI OPTIONAL,
diff --git a/lib/asn1/test/asn1_SUITE_data/testobj.erl b/lib/asn1/test/asn1_SUITE_data/testobj.erl
index b582935f73..c358c26623 100644
--- a/lib/asn1/test/asn1_SUITE_data/testobj.erl
+++ b/lib/asn1/test/asn1_SUITE_data/testobj.erl
@@ -1,7 +1,7 @@
%%
%% %CopyrightBegin%
%%
-%% Copyright Ericsson AB 2001-2017. All Rights Reserved.
+%% Copyright Ericsson AB 2001-2021. All Rights Reserved.
%%
%% Licensed under the Apache License, Version 2.0 (the "License");
%% you may not use this file except in compliance with the License.
@@ -427,7 +427,7 @@ run_sm_cmd() ->
{_ProtIEField2,11,_Crit2,DecEI},
{_ProtIEField3,75,_Crit3,DecKS}],
_ASN1novalue} ->
- io:format("Integrity Protection Algoritm: ~w~n~n", [DecIPI]),
+ io:format("Integrity Protection Algorithm: ~w~n~n", [DecIPI]),
io:format("Encryption Information: ~w~n~n", [DecEI]),
io:format("Key Status: ~w~n~n", [DecKS])
end,
@@ -452,7 +452,7 @@ run_sm_cmp() ->
[{_ProtIEField1,6,_Crit1,DecIPA},
{_ProtIEField2,5,_Crit2,DecEI}],
_ASN1novalue} ->
- io:format("Integrity Protection Algoritm: ~w~n~n", [DecIPA]),
+ io:format("Integrity Protection Algorithm: ~w~n~n", [DecIPA]),
io:format("Encryption Information: ~w~n~n", [DecEI])
end,
ok.
@@ -480,7 +480,7 @@ run_sm_rej() ->
% io:format("Value2: ~w~n~n", [Value2]),
% {ok,DecIPA} = wrapper_decode(?ranap, 'IntegrityProtectionAlgorithm', Value1),
% {ok,DecEI} = wrapper_decode(?ranap, 'EncryptionAlgorithm', Value2),
% io:format("Integrity Protection Algoritm: ~w~n~n", [DecIPA]),
% io:format("Encryption Information: ~w~n~n", [DecEI])
% end,
ok.
@@ -563,7 +563,7 @@ run_reset() ->
run_reset_res() ->
IUP = reset_res([12,13,14,15,16,17,18,19,20]),
- io:format("Reset Rsource: ~w~n~n", [IUP]),
+ io:format("Reset Resource: ~w~n~n", [IUP]),
RanapIUP = ranap_pdu_contents(IUP, 27), % 27 = Reset Res
{ok, Tmp2} = wrapper_encode(?ranap, 'RANAP-PDU', RanapIUP),
EncRanapIUP = lists:flatten(Tmp2),
@@ -1390,7 +1390,7 @@ reset_res_ack(IuSCId) ->
reset_res_ack_ies(IuSCId) ->
[
cn_domain_ind() % Se initial Ue
- ,reset_res_list(IuSCId) % Se Reset Ressource
+ ,reset_res_list(IuSCId) % Se Reset Resource
].
@@ -480,7 +480,7 @@ run_sm_rej() ->
% {ok,DecIPA} = wrapper_decode(?ranap, 'IntegrityProtectionAlgorithm', Value1),
% {ok,DecEI} = wrapper_decode(?ranap, 'EncryptionAlgorithm', Value2),
-% io:format("Integrity Protection Algoritm: ~w~n~n", [DecIPA]),
+% io:format("Integrity Protection Algorithm: ~w~n~n", [DecIPA]),
% io:format("Encryption Information: ~w~n~n", [DecEI])
% end,